@@ -1,7 +1,7 @@
 package Bencher::Scenario::SortSub::naturally;
 
-our $DATE = '2017-01-19'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -12,6 +12,7 @@ use Sort::Sub qw($naturally);
 our $scenario = {
     summary => 'Benchmark natural sorting',
     modules => {
+        'Sort::Sub' => {version=>'0.05'},
     },
     participants => [
         {
@@ -62,7 +63,7 @@ Bencher::Scenario::SortSub::naturally - Benchmark natural sorting
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::SortSub::naturally (from Perl distribution Bencher-Scenarios-SortSub), released on 2017-01-19.
+This document describes version 0.003 of Bencher::Scenario::SortSub::naturally (from Perl distribution Bencher-Scenarios-SortSub), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -153,20 +154,20 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2
 Benchmark with default options (C<< bencher -m SortSub::naturally >>):
 
  #table1#
- +----------------------------+----------+-----------+------------+------------+---------+---------+
- | participant                | dataset  | rate (/s) |  time (ms) | vs_slowest |  errors | samples |
- +----------------------------+----------+-----------+------------+------------+---------+---------+
- | Sort::Naturally::nsort     | 100items |       637 | 1.57       |      1     | 6.9e-07 |      20 |
- | Sort::Naturally::XS::nsort | 100items |      7890 | 0.127      |     12.4   | 5.3e-08 |      20 |
- | Sort::Naturally::nsort     | 10items  |     13100 | 0.0762     |     20.6   | 2.7e-08 |      20 |
- | Sort::Naturally::XS::nsort | 10items  |    165000 | 0.00605    |    259     | 1.5e-09 |      24 |
- | Sort::Naturally::ncmp      | 100items |    230160 | 0.0043449  |    361.15  | 1.1e-11 |      20 |
- | Sort::Sub::naturally       | 100items |    230270 | 0.0043428  |    361.32  | 1.1e-11 |      20 |
- | Sort::Naturally::XS::ncmp  | 100items |    232645 | 0.0042984  |    365.051 |   0     |      36 |
- | Sort::Naturally::XS::ncmp  | 10items  |   1781000 | 0.0005614  |   2795     | 1.1e-11 |      20 |
- | Sort::Sub::naturally       | 10items  |   1790290 | 0.00055857 |   2809.2   |   0     |      20 |
- | Sort::Naturally::ncmp      | 10items  |   1815000 | 0.000551   |   2848     | 1.2e-11 |      20 |
- +----------------------------+----------+-----------+------------+------------+---------+---------+
+ +----------------------------+----------+-----------+-----------+------------+---------+---------+
+ | participant                | dataset  | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +----------------------------+----------+-----------+-----------+------------+---------+---------+
+ | Sort::Naturally::nsort     | 100items |       600 |  1.7      |        1   | 1.1e-05 |      21 |
+ | Sort::Naturally::XS::nsort | 100items |      7020 |  0.142    |       11.7 | 4.7e-08 |      26 |
+ | Sort::Naturally::nsort     | 10items  |     13000 |  0.075    |       22   | 8.4e-08 |      32 |
+ | Sort::Naturally::XS::nsort | 10items  |    150000 |  0.0065   |      260   | 8.9e-09 |      25 |
+ | Sort::Naturally::ncmp      | 100items |    207000 |  0.00482  |      347   | 1.4e-09 |      28 |
+ | Sort::Naturally::XS::ncmp  | 100items |    200000 |  0.005    |      400   | 7.7e-08 |      20 |
+ | Sort::Sub::naturally       | 100items |    232100 |  0.004309 |      388.3 | 8.5e-11 |      20 |
+ | Sort::Naturally::ncmp      | 10items  |   1580000 |  0.000634 |     2640   | 2.1e-10 |      20 |
+ | Sort::Naturally::XS::ncmp  | 10items  |   1600000 |  0.00063  |     2700   | 1.6e-09 |      22 |
+ | Sort::Sub::naturally       | 10items  |   1600000 |  0.000626 |     2670   |   2e-10 |      22 |
+ +----------------------------+----------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m SortSub::naturally --module-startup >>):
@@ -175,10 +176,10 @@ Benchmark module startup overhead (C<< bencher -m SortSub::naturally --module-st
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Sort::Naturally::XS | 1.38                         | 4.82               | 18.5           |      11.8 |                    6.4 |        1   | 8.9e-06 |      20 |
- | Sort::Naturally     | 1.2                          | 4.7                | 16             |      11   |                    5.6 |        1   | 4.6e-05 |      20 |
- | Sort::Sub           | 1.2                          | 4.7                | 16             |       7.9 |                    2.5 |        1.5 | 2.9e-05 |      20 |
- | perl -e1 (baseline) | 0.86                         | 4.3                | 16             |       5.4 |                    0   |        2.2 | 1.2e-05 |      20 |
+ | Sort::Naturally::XS | 1.4                          | 4.8                | 19             |      11   |                    6.7 |        1   | 3.4e-05 |      20 |
+ | Sort::Naturally     | 1.2                          | 4.6                | 16             |      10   |                    5.7 |        1   | 8.7e-05 |      20 |
+ | Sort::Sub           | 1.2                          | 4.6                | 16             |       6.9 |                    2.6 |        1.6 | 2.7e-05 |      21 |
+ | perl -e1 (baseline) | 0.87                         | 4.3                | 16             |       4.3 |                    0   |        2.5 | 8.3e-06 |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
