@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::SortSub::naturally;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -9,93 +9,93 @@ our $results = [
     [
       {
         dataset     => "100items",
-        errors      => 6.9e-07,
+        errors      => 1.1e-05,
         participant => "Sort::Naturally::nsort",
-        rate        => 637,
-        samples     => 20,
-        time        => 1.57,
+        rate        => 600,
+        samples     => 21,
+        time        => 1.7,
         vs_slowest  => 1,
       },
       {
         dataset     => "100items",
-        errors      => 5.3e-08,
+        errors      => 4.7e-08,
         participant => "Sort::Naturally::XS::nsort",
-        rate        => 7890,
-        samples     => 20,
-        time        => 0.127,
-        vs_slowest  => 12.4,
+        rate        => 7020,
+        samples     => 26,
+        time        => 0.142,
+        vs_slowest  => 11.7,
       },
       {
         dataset     => "10items",
-        errors      => 2.7e-08,
+        errors      => 8.4e-08,
         participant => "Sort::Naturally::nsort",
-        rate        => 13100,
-        samples     => 20,
-        time        => 0.0762,
-        vs_slowest  => 20.6,
+        rate        => 13000,
+        samples     => 32,
+        time        => 0.075,
+        vs_slowest  => 22,
       },
       {
         dataset     => "10items",
-        errors      => 1.5e-09,
+        errors      => 8.9e-09,
         participant => "Sort::Naturally::XS::nsort",
-        rate        => 165000,
-        samples     => 24,
-        time        => 0.00605,
-        vs_slowest  => 259,
+        rate        => 150000,
+        samples     => 25,
+        time        => 0.0065,
+        vs_slowest  => 260,
       },
       {
         dataset     => "100items",
-        errors      => 1.1e-11,
+        errors      => 1.4e-09,
         participant => "Sort::Naturally::ncmp",
-        rate        => 230160,
-        samples     => 20,
-        time        => 0.0043449,
-        vs_slowest  => 361.15,
+        rate        => 207000,
+        samples     => 28,
+        time        => 0.00482,
+        vs_slowest  => 347,
       },
       {
         dataset     => "100items",
-        errors      => 1.1e-11,
-        participant => "Sort::Sub::naturally",
-        rate        => 230270,
+        errors      => 7.7e-08,
+        participant => "Sort::Naturally::XS::ncmp",
+        rate        => 200000,
         samples     => 20,
-        time        => 0.0043428,
-        vs_slowest  => 361.32,
+        time        => 0.005,
+        vs_slowest  => 400,
       },
       {
         dataset     => "100items",
-        errors      => 0,
-        participant => "Sort::Naturally::XS::ncmp",
-        rate        => 232645,
-        samples     => 36,
-        time        => 0.0042984,
-        vs_slowest  => 365.051,
-      },
-      {
-        dataset     => "10items",
-        errors      => 1.1e-11,
-        participant => "Sort::Naturally::XS::ncmp",
-        rate        => 1781000,
-        samples     => 20,
-        time        => 0.0005614,
-        vs_slowest  => 2795,
-      },
-      {
-        dataset     => "10items",
-        errors      => 0,
+        errors      => 8.5e-11,
         participant => "Sort::Sub::naturally",
-        rate        => 1790290,
+        rate        => 232100,
         samples     => 20,
-        time        => 0.00055857,
-        vs_slowest  => 2809.2,
+        time        => 0.004309,
+        vs_slowest  => 388.3,
       },
       {
         dataset     => "10items",
-        errors      => 1.2e-11,
+        errors      => 2.1e-10,
         participant => "Sort::Naturally::ncmp",
-        rate        => 1815000,
+        rate        => 1580000,
         samples     => 20,
-        time        => 0.000551,
-        vs_slowest  => 2848,
+        time        => 0.000634,
+        vs_slowest  => 2640,
+      },
+      {
+        dataset     => "10items",
+        errors      => 1.6e-09,
+        participant => "Sort::Naturally::XS::ncmp",
+        rate        => 1600000,
+        samples     => 22,
+        time        => 0.00063,
+        vs_slowest  => 2700,
+      },
+      {
+        dataset     => "10items",
+        errors      => 2e-10,
+        participant => "Sort::Sub::naturally",
+        rate        => 1600000,
+        samples     => 22,
+        time        => 0.000626,
+        vs_slowest  => 2670,
       },
     ],
     {
@@ -218,7 +218,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2663.062,
+                                              speed                        => "2877.710",
                                               stepping                     => 4,
                                             },
                                             {
@@ -333,7 +333,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2815.804,
+                                              speed                        => 2666.453,
                                               stepping                     => 4,
                                             },
                                             {
@@ -448,7 +448,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2893.734,
+                                              speed                        => "2893.570",
                                               stepping                     => 4,
                                             },
                                             {
@@ -563,21 +563,22 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2896.632,
+                                              speed                        => 2884.164,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.301789045333862,
+      "func.elapsed_time"              => 0.317187070846558,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__"                           => 1.034,
                                             "Bencher::Scenario::SortSub::naturally" => undef,
-                                            "Benchmark::Dumb" => "0.10",
-                                            "Devel::Platform::Info" => 0.16,
-                                            "perl" => "v5.24.0",
-                                            "Sort::Naturally" => 1.03,
-                                            "Sort::Naturally::XS" => "0.7.3",
-                                            "Sort::Sub" => "0.10",
-                                            "Sys::Info" => 0.78,
+                                            "Benchmark::Dumb"                       => "0.10",
+                                            "Devel::Platform::Info"                 => 0.16,
+                                            "perl"                                  => "v5.24.0",
+                                            "Sort::Naturally"                       => 1.03,
+                                            "Sort::Naturally::XS"                   => "0.7.3",
+                                            "Sort::Sub"                             => "0.10",
+                                            "Sys::Info"                             => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
       "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 4], "dataset", [0, 1]],
@@ -606,13 +607,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::SortSub::naturally",
-      "func.scenario_module_md5sum"    => "8de281206109be603ba2c1eced75210e",
-      "func.scenario_module_mtime"     => 1484794392,
-      "func.scenario_module_sha1sum"   => "037c36fdaa436b0bd4e1932b684a129517bf7b21",
-      "func.scenario_module_sha256sum" => "e116f54293d4153b034a6587faf3ef721792dea2f17563a59a1b5a64343cd94c",
-      "func.time_end"                  => 1484794508.4339,
+      "func.scenario_module_md5sum"    => "1650bb84fe53e137a38ac3ee815d9474",
+      "func.scenario_module_mtime"     => 1485332883,
+      "func.scenario_module_sha1sum"   => "0269056217892a462dfb09be421544cbd09f500d",
+      "func.scenario_module_sha256sum" => "4975098dd7cf989395863bc36ac345608c6f4b5297ad0c688625def7638adc4c",
+      "func.time_end"                  => 1485332893.22842,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1484794508.13211,
+      "func.time_start"                => 1485332892.91124,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
